@@ -13,15 +13,15 @@ from .constants import (
 
 @dataclass(frozen=True)
 class EventClientConfig:
-    """Configuration object for EventClient initialization.
+    """Configuration for the Chaturbate Events API client.
 
     Attributes:
-        timeout (int): Timeout for API requests in seconds. Default is 10.
-        use_testbed (bool): Whether to use the testbed API endpoint. Default is False.
-        retry_attempts (int): Number of retry attempts for failed requests. Default is 8.
-        retry_backoff (float): Initial backoff time in seconds between retries. Default is 1.0.
-        retry_exponential_base (float): Base for exponential backoff calculation. Default is 2.0.
-        retry_max_delay (float): Maximum delay in seconds between retries. Default is 30.0.
+        timeout: Timeout for API requests in seconds.
+        use_testbed: Whether to use the testbed API endpoint instead of production.
+        retry_attempts: Number of retry attempts for failed requests.
+        retry_backoff: Initial backoff time in seconds for exponential retry.
+        retry_exponential_base: Base multiplier for exponential backoff calculation.
+        retry_max_delay: Maximum delay between retries in seconds.
     """
 
     timeout: int = DEFAULT_TIMEOUT
